..  Core documentation master file, created by
    sphinx-quickstart on Mon Oct 12 12:49:48 2015.
    You can adapt this file completely to your liking, but it should at least
    contain the root `toctree` directive.

Eliza
=====

As we write micro-services, we write micro-tools and as a consequence we end up with multiple small ones.
Nevertheless we want to have a consistent look and feel, without bothering to write/provide the same functionality/resources.

This library is targeted specifically to developers who want to create lightweight web-based tools based on python and flask.

It provides core functions to Python Microservices so that the services itself can concentrate on its main function and become even smaller.

Guide
=====

.. toctree::
    :maxdepth: 2

    install
    config
    code
    contribution
    license


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`